BlockedServer class

Represents a blocked server that the player shouldn't be allowed to join.

Constructors

BlockedServer(String addressSha1, String? address)
A blocked server that the player shouldn't be allowed to join
const
BlockedServer.parse(String addressSha1)
Parse the address and check if it is included in _knownCrackedServers and if so, add the cracked address to it.
factory

Properties

address → String?
The address of the server. Only available if the server has been 'cracked'.
final
addressSha1 → String
The SHA1 of the address of the server.
final
hashCode → int
The hash code for this object.
no setteroverride
isCracked → bool
Whether the SHA1 of this blocked server has been cracked and the actual address is known.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override