LegacyProfileTextures class

Represents all textures for a legacy minecraft profile.

Constructors

LegacyProfileTextures.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Get the player's name
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skinModel → SkinModel
Get the skin model of the skin.
no setter
timestamp → DateTime
Get the timestamp
no setter

Methods

capeUrl() → String
Get the url to the cape texture.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
skinUrl() → String
Get the Url for the skin of this player. If the player does not have a skin, this function will return the link to the steve or alex skin.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited