MinecraftNews class

A Minecraft News item.

Constructors

MinecraftNews.fromJson(Map<String, dynamic> data)

Properties

category → String
The category of this news article, e.g. "Minecraft: Java Edition"
final
date → DateTime
Get's the date at which this article was published. Note that this is always at midnight, as the original timestamp does not provide any hours/minutes.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
The id of this news item.
final
imageUrl → String
Get's the url to the image of this news item. News images are usually 1200x512 pixels in size.
no setter
important → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String
final
text → String
The description of this news. Formatted in HTML.
final
title → String
The title of this news item.
final
url → String
The url to this news article on https://minecraft.net.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited