ProfileTexture class

Represents a single texture for a minecraft profile. Could be a cape or skin.

Constructors

ProfileTexture(String id, String url, [String? alias, SkinModel? model])

Properties

alias ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
The ID of the texture or the profile.
getter/setter pair
model ↔ SkinModel?
The skin model of this texture. Might be null if this is a cape.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited