Version class

A Minecraft Version.

Constructors

Version.fromJson(Map<String, dynamic> data)

Properties

complianceLevel ↔ int
The level of compliance of this client. Used to indicate version of player safety features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
The Minecraft Version ID, e.g. "1.16.3"
getter/setter pair
releaseDateTime → DateTime
The time this version was release at as a DateTime object.
no setter
releaseTime ↔ String
The time this version was release at.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1 ↔ String
A SHA1 hash of the version package.
getter/setter pair
time ↔ String
Some time that is usually just minutes after releaseTime.
getter/setter pair
timeDateTime → DateTime
Some time that is usually just minutes after releaseTime as a DateTime object.
no setter
type ↔ String
The type of this Minecraft Version, e.g. "snapshot" or "release";
getter/setter pair
url ↔ String
The URL to the manifest of this version. This manifest includes libraries, command line arguments and more configuration for this version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited