VersionManifest class

A manifest of all currently available Minecraft Versions. Also has latest release and snapshot versions.

Constructors

VersionManifest.fromJson(Map<String, dynamic> data)

Properties

hashCode → int
The hash code for this object.
no setterinherited
latestRelease ↔ String
The latest available stable release of Minecraft: Java Edition.
getter/setter pair
latestSnapshot ↔ String
The latest available beta snapshot of Minecraft: Java Edition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versions ↔ List<Version>
A list of all available versions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited