NbtFloat class

Represents a 4 byte single precision floating point number in a NBT file.

Inheritance

Constructors

NbtFloat({required String name, required double value})
Creates a NbtFloat with given parent.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasLength → bool
If the tag is a List and has a length
no setterinherited
hasValue → bool
If this tag directly has a value.
no setterinherited
name ↔ String
The name of this tag. Inside of Lists or Arrays, this is 'None'.
getter/setter pairinherited
nbtTagType → NbtTagType
The type of this tag.
no setterinherited
parent ↔ NbtTag?
The parent of this tag. Can only be null for the root NbtCompound.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
The value of this tag. Can vary depending on tag type, obtainable from nbtTagType.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readTag(NbtReader nbtReader, {bool withName = true}) → NbtFloat
Reads a NbtTag from fileReader. If the parent is a NbtList or NbtArray, withName should be set to false to avoid reading the name of this Tag.
override
toString() → String
A string representation of this object.
inherited
writeTag(NbtWriter nbtWriter, {bool withName = true, bool withType = true}) → void
Writes a NbtTag from fileReader. If the parent is a NbtList or NbtArray, withName should be set to false to avoid writing any names of this Tag.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited