NbtTagType enum
Different tags for each Nbt Tag that exists.
- Inheritance
- Available extensions
Values
- TAG_END → const NbtTagType
-
A NBT Tag used to indicate the end of a NbtCompound.
- TAG_BYTE → const NbtTagType
-
A named NBT Tag used to store a single byte.
- TAG_SHORT → const NbtTagType
-
A named NBT Tag used to store a single big endian signed 2 byte short integer.
- TAG_INT → const NbtTagType
-
A named NBT Tag used to store a single big endian signed 4 byte integer.
- TAG_LONG → const NbtTagType
-
A named NBT Tag to store a single big endian signed 8 byte long integer.
- TAG_FLOAT → const NbtTagType
-
A named NBT Tag used to store a single 4 byte single precision floating point number.
- TAG_DOUBLE → const NbtTagType
-
A named NBT Tag used to store a single 8 byte double precision floating point number.
- TAG_BYTE_ARRAY → const NbtTagType
-
A named NBT Tag used to store a list of unnamed single bytes.
- TAG_STRING → const NbtTagType
-
A named NBT Tag used to store a single String.
- TAG_LIST → const NbtTagType
-
A named NBT Tag used to store a List of unnamed NBT Tags, all of which are from the same type.
- TAG_COMPOUND → const NbtTagType
-
A named NBT Tag used to store a List of named NBT Tags of any type.
- TAG_INT_ARRAY → const NbtTagType
-
A named NBT Tag used to store a list of unnamed big endian signed 4 byte integers.
- TAG_LONG_ARRAY → const NbtTagType
-
A named NBT Tag used to store a list of unnamed big endian signed 8 byte long integers.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asString(
) → String -
Available on NbtTagType, provided by the NbtTagFunctions extension
Gets a string representation of this tag. The default toString() cannot be overridden by extensions and returns "NbtTagType.TAG_END", instead of "TAG_END" or "TAG_End", which is shorter and more helpful in the end. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NbtTagType> - A constant List of the values in this enum, in order of their declaration.