MinecraftStatisticsItem enum
Statistics items that can be selected.
- Inheritance
- Available extensions
Values
- minecraftItemsSold → const MinecraftStatisticsItem
-
The total amount of Minecraft Sales.
- minecraftPrepaidCardsRedeemed → const MinecraftStatisticsItem
- cobaltItemsSold → const MinecraftStatisticsItem
-
The total amount of Cobalt Sales.
- scrollsItemsSold → const MinecraftStatisticsItem
-
The total amount of Scrolls Sales.
- cobaltPrepaidCardsRedeemed → const MinecraftStatisticsItem
- dungeonsItemsSold → const MinecraftStatisticsItem
-
The total amount of Minecraft: Dungeons Sales.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - name → String?
-
Available on MinecraftStatisticsItem, provided by the MinecraftStatisticsItemExt extension
Returns the API version of this item.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MinecraftStatisticsItem> - A constant List of the values in this enum, in order of their declaration.